#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-CMqKCqY9qQVG1BmabWHJtd
key:                  modern-uri-0.3.6.1-CMqKCqY9qQVG1BmabWHJtd
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  d2d9bf424d33eba3d8dab5f78ac0de66
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-CMqKCqY9qQVG1BmabWHJtd
depends:
    QuickCheck-2.15.0.1-K3lipsQVw823tgNiuMuKMC base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    exceptions-0.10.7 hashable-1.4.7.0-DjTaTzSxyhZLemTcoX34jw
    megaparsec-9.7.1-IJJCy7AfSWn4uupFAyXCnh mtl-2.3.1
    profunctors-5.6.3-Ja9DdZHwt3VKYDSvMIGSM6
    reflection-2.1.9-7zNyNBslWF6Khz2Zec4jol
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

